//
//  GBSlidingMenu.m
//  SlidingMenu
//
//  Created by Julien Gomes on 8/20/12.
//  Copyright (c) 2012 Gomes Brothers. All rights reserved.
//

#import "GBSlideOutController.h"

#define ANIMATION_DURATION 0.5
#define ANIMATION_DELAY 0
#define MENU_BUTTON 50

@implementation GBSlideOutController

@synthesize menuViewController;
@synthesize contentViewController;
@synthesize viewControllers;

- (id)initWithViewControllers:(NSArray *)allViewControllers
{
    self = [super init];
    if (self) {
        viewControllers = allViewControllers;
        [viewControllers retain];
    }
    return self;
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

#pragma mark - View lifecycle

- (void) viewDidLoad{
    _mainViewDimensionsDisplayed = self.view.bounds;
    _mainViewDimensionsHidden = CGRectMake(_mainViewDimensionsDisplayed.size.width-MENU_BUTTON, _mainViewDimensionsDisplayed.origin.y, _mainViewDimensionsDisplayed.size.width, _mainViewDimensionsDisplayed.size.height);
    _currentMainViewDimensions = _mainViewDimensionsDisplayed;
    _isMenuHidden = YES;
    
    if(viewControllers != nil && [viewControllers count] > 0){        
        [self.view addSubview:self.menuViewController.view];
        [self displayController:[viewControllers objectAtIndex:0]];
    }
}

- (void) createContentViewcontroller:(UIViewController *)viewController{
    self.contentViewController = [[UINavigationController alloc] initWithRootViewController:currentViewController];
    self.contentViewController.navigationBar.barStyle = UIBarStyleBlack;
    [self.contentViewController.view setFrame:_currentMainViewDimensions];
    viewController.navigationItem.leftBarButtonItem = [[UIBarButtonItem alloc] initWithImage:[UIImage imageNamed:@"ButtonMenu.png"]  style:UIBarButtonItemStyleBordered target:self action:@selector(displayMenu:)];
    [self.view addSubview:self.contentViewController.view];
}

#pragma mark - Display Menu

- (void) displayMenu:(id)sender{
    if(_isMenuHidden){
        [self displayMenu];
    }else{
        [self hideMenu];
    }
}

- (void) displayMenu{
    [UIView animateWithDuration:ANIMATION_DURATION
                          delay:ANIMATION_DELAY
                        options:UIViewAnimationOptionTransitionNone
                     animations:^{
                         [self.contentViewController.view setFrame:_mainViewDimensionsHidden];
                     }
                     completion:^(BOOL finished){
                         _isMenuHidden = NO;
                         _currentMainViewDimensions = _mainViewDimensionsHidden;
                     }];
}

- (void) hideMenu{
    [UIView animateWithDuration:ANIMATION_DURATION
                          delay:ANIMATION_DELAY
                        options:UIViewAnimationOptionTransitionNone
                     animations:^{
                         [self.contentViewController.view setFrame:_mainViewDimensionsDisplayed];
                     }
                     completion:^(BOOL finished){
                         _isMenuHidden = YES;
                         _currentMainViewDimensions = _mainViewDimensionsDisplayed;
                     }];
}

#pragma mark - Controller Management

- (void) displayControllerAtIndex:(NSUInteger)index{
    if(index < [viewControllers count]){
        [self displayController:[viewControllers objectAtIndex:index]];
    }
    [self hideMenu];
}

- (void) displayController:(UIViewController *)viewController{
    currentViewController = viewController;
    [self.contentViewController.view removeFromSuperview];
    [self.contentViewController release];
    [self createContentViewcontroller:viewController];
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}

- (void) dealloc {
    [self.contentViewController release];
    [self.menuViewController release];
    [viewControllers release];
}

@end
